@@ -7,13 +7,14 @@
             [puppetlabs.puppetdb.middleware :refer [wrap-with-globals
                                                     wrap-with-metrics
                                                     wrap-with-illegal-argument-catch
+                                                    wrap-with-exception-handling
                                                     verify-accepts-json
                                                     verify-content-type
-                                                    make-pdb-handler]]
-            [ring.util.response :as rr]
+                                                    make-pdb-handler
+                                                    verify-sync-version]]
             [puppetlabs.comidi :as cmdi]
             [puppetlabs.puppetdb.http.handlers :as handlers]
-            [puppetlabs.i18n.core :refer [trs tru]]))
+            [puppetlabs.i18n.core :refer [tru]]))
 
 (defn- refuse-retired-api
   [version]
@@ -51,6 +52,8 @@
                 "/producers" handlers/producers-routes
                 "/resources" handlers/resources-routes
                 "/catalogs" handlers/catalog-routes
+                "/catalog-input-contents" handlers/catalog-input-contents-routes
+                "/catalog-inputs" handlers/catalog-inputs-routes
                 "/events" handlers/events-routes
                 "/event-counts" handlers/event-counts-routes
                 "/aggregate-event-counts" handlers/agg-event-counts-routes
@@ -69,6 +72,9 @@
                       wrap-with-illegal-argument-catch
                       verify-accepts-json
                       (verify-content-type ["application/json"])
+                      verify-sync-version
                       (wrap-with-metrics (atom {}) http/leading-uris)
-                      (wrap-with-globals get-shared-globals))]
+                      (wrap-with-globals get-shared-globals)
+                      wrap-with-exception-handling)]
+
       (handler req))))
