@@ -1,9 +1,8 @@
 (ns puppetlabs.trapperkeeper.services.webrouting.webrouting-service-core
-  (:import (javax.servlet ServletContextListener))
-  (:require [schema.core :as schema]
-            [puppetlabs.trapperkeeper.services.webserver.jetty9-config :as config]
-            [puppetlabs.trapperkeeper.services.webserver.jetty9-core :as jetty9-core]
-            [puppetlabs.trapperkeeper.services :as tk-services]))
+  (:require [puppetlabs.i18n.core :as i18n]
+            [puppetlabs.trapperkeeper.services :as tk-services]
+            [puppetlabs.trapperkeeper.services.webserver.jetty10-core :as jetty10-core]
+            [schema.core :as schema]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Schemas
@@ -22,16 +21,16 @@
   {(schema/optional-key :route-id) schema/Keyword})
 
 (def CommonOptions
-  (dissoc (merge jetty9-core/CommonOptions RouteOption) :server-id))
+  (dissoc (merge jetty10-core/CommonOptions RouteOption) :server-id))
 
 (def ContextHandlerOptions
-  (dissoc (merge jetty9-core/ContextHandlerOptions RouteOption) :server-id))
+  (dissoc (merge jetty10-core/ContextHandlerOptions RouteOption) :server-id))
 
 (def ServletHandlerOptions
-  (dissoc (merge jetty9-core/ServletHandlerOptions RouteOption) :server-id))
+  (dissoc (merge jetty10-core/ServletHandlerOptions RouteOption) :server-id))
 
 (def ProxyRouteOptions
-  (dissoc (merge jetty9-core/ProxyOptions RouteOption) :server-id))
+  (dissoc (merge jetty10-core/ProxyOptions RouteOption) :server-id))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Private Utility Functions
@@ -50,17 +49,20 @@
         no-server?      (nil? (schema/check schema/Str endpoint))
         server?         (nil? (schema/check RouteWithServerConfig endpoint))]
     (cond
-      no-service?     (throw
-                        (IllegalArgumentException.
-                          (str "service " svc " does not appear in configuration")))
-      no-endpoint?    (throw
-                        (IllegalArgumentException.
-                          (str "endpoint with id " route-id " does not appear in configuration "
-                               "for service " svc)))
+      no-service?
+      (throw
+        (IllegalArgumentException.
+          (i18n/trs "service {0} does not appear in configuration" svc)))
+      no-endpoint?
+      (throw
+        (IllegalArgumentException.
+          (i18n/trs "endpoint with id {0} does not appear in configuration for service {1}"
+               route-id
+               svc)))
       (and no-route-id? multi-route?)
-                      (throw
-                        (IllegalArgumentException.
-                          "no route-id specified for a service with multiple routes"))
+      (throw
+        (IllegalArgumentException.
+          (i18n/trs "no route-id specified for a service with multiple routes")))
       no-server?      {:route endpoint :server nil}
       server?         endpoint)))
 
@@ -85,9 +87,10 @@
   (let [configuration (into {} (for [[svc svc-config] config]
                                  (cond
                                    (nil? (schema/check (schema/either schema/Str RouteWithServerConfig) svc-config))
-                                     [svc {:default svc-config}]
+                                   [svc {:default svc-config}]
+
                                    (nil? (schema/check WebroutingMultipleConfig svc-config))
-                                     [svc svc-config])))]
+                                   [svc svc-config])))]
     (assoc context :web-router-service configuration)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
